pub fn rtc_calib_cal_mv(_unit: AdcCalibUnit, atten: Attenuation) -> u16Available on crate feature
unstable only.Expand description
Get ADC calibration coefficients
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.