rtc_calib_get_chan_compens

Function rtc_calib_get_chan_compens 

pub fn rtc_calib_get_chan_compens(
    _unit: AdcCalibUnit,
    channel: u16,
    atten: Attenuation,
) -> Option<i32>
Available on crate feature unstable only.
Get the channel specific calibration compensation

see https://github.com/espressif/esp-idf/blob/caf1a18/components/efuse/esp32c5/esp_efuse_rtc_calib.c#L60

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.