xtal_frequency_mhz

Function xtal_frequency_mhz 

pub fn xtal_frequency_mhz() -> u32
Available on crate feature unstable only.
Returns the frequency of the crystal oscillator in MHz

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.